export const materials = {
    default: {
        strokeStyle: {
            lineWidth: 0.01,
            color: new Uint8ClampedArray([0, 0, 0]),
            opacity: 1
        }
    },
    highlighted: {
        strokeStyle: {
            lineWidth: 0.03,
            color: new Uint8ClampedArray([0, 0, 255]),
            opacity: 1
        },
        fillStyle: {
            color: new Uint8ClampedArray([0, 0, 200]),
            opacity: 0.1
        },
    },
    selected: {
        strokeStyle: {
            lineWidth: 0.05,
            color: new Uint8ClampedArray([0, 255, 0]),
            opacity: 1
        },
        fillStyle: {
            color: new Uint8ClampedArray([0, 200, 0]),
            opacity: 0.4
        },
    },
    xrayed: {
        strokeStyle: {
            lineWidth: 0.01,
            color: new Uint8ClampedArray([100, 100, 0]),
            opacity: 0.2
        },
    }
}

export function blendMaterials(materials = []) {
    const strokeStyles = materials.map(mat => mat.strokeStyle).filter(Boolean);

    const strokeLineWidth = average(strokeStyles.map(strokeStyle => strokeStyle.lineWidth).filter(Boolean));
    const strokeColor = blendColors(strokeStyles.map(strokeStyle => strokeStyle.color).filter(Boolean));
    const strokeOpacity = average(strokeStyles.map(strokeStyle => strokeStyle.opacity).filter(Boolean));

    const fillStyles = materials.map(mat => mat.fillStyle).filter(Boolean);

    const fillColor = blendColors(fillStyles.map(fillStyle => fillStyle.color).filter(Boolean));
    const fillOpacity = average(fillStyles.map(fillStyle => fillStyle.opacity).filter(Boolean));

    const material = {}
    if (strokeColor) {
        material.strokeStyle = {
            lineWidth: strokeLineWidth,
            color: strokeColor,
            opacity: strokeOpacity
        }
    }
    if (fillColor) {
        material.fillStyle = {
            color: fillColor,
            opacity: fillOpacity
        }
    }
    return material;
}

function blendColors(colors = []) {
    if (colors.length) {
        return colors.reduce((acc, cur, i, arr) => i === arr.length - 1 ?
            new Uint8ClampedArray([acc[0] + cur[0] / arr.length, acc[1] + cur[1] / arr.length, acc[2] + cur[2] / arr.length]) :
            new Uint8ClampedArray([acc[0] + cur[0], acc[1] + cur[1], acc[2] + cur[2]]));
    }
}

function average(numbers = []) {
    if (numbers.length) {
        return numbers.reduce((acc, cur) => acc + cur) / numbers.length;
    }
}
