export default async function loadSvgModel(svgUri) {
  const res = await fetch(svgUri);
  const svgString = await res.text();
  const svg = new DOMParser().parseFromString(svgString, "image/svg+xml");

  function parseAttribute(attribute) {
    return (
      (svg.firstChild.getAttribute(attribute) || "").match(/-?\d*\.\d*/g) || []
    ).map(parseFloat);
  }

  return {
    elevations: parseAttribute("storeys-elevation"),
    bbox: JSON.parse(svg.firstChild.getAttribute("bounds")).flat(),
    objects: Array.from(svg.firstChild.getElementsByTagName("g")).map(g => ({
      id: g.id,
      area: g.getAttribute("area"),
      elevationTop: Number(g.getAttribute("elevation-top")),
      elevationBottom: Number(g.getAttribute("elevation-bottom")),
      type: g.getAttribute("ifc-type"),
      bbox: JSON.parse(g.getAttribute("bounds")).flat(),
      path: new Path2D(g.firstElementChild.getAttribute("d")),
      nodePath: g.firstElementChild.getAttribute("d"),
      visible: true,
      selected: false,
      xrayed: false,
      highlighted: false,
      pickable: true
    }))
  };
}
